@@ -433,11 +433,10 @@ describe('use extension', () => {
             const token = {
               type: 'walkableDescription',
               raw: match[0],
-              dt: [],
+              dt: this.lexer.inline(match[1].trim()),
               dd: [],
               tokens: []
             };
-            this.lexer.inline(match[1].trim(), token.dt);
             this.lexer.inline(match[2].trim(), token.dd);
             this.lexer.inline('unwalked', token.tokens);
             return token;
@@ -1059,4 +1058,23 @@ br
     });
     expect(marked('*text*').trim()).toBe('<p><em>text walked</em></p>');
   });
+
+  it('should wait for async `walkTokens` function', async() => {
+    marked.use({
+      async: true,
+      async walkTokens(token) {
+        if (token.type === 'em') {
+          await new Promise((resolve) => {
+            setTimeout(resolve, 100);
+          });
+          token.text += ' walked';
+          token.tokens = this.Lexer.lexInline(token.text);
+        }
+      }
+    });
+    const promise = marked('*text*');
+    expect(promise).toBeInstanceOf(Promise);
+    const html = await promise;
+    expect(html.trim()).toBe('<p><em>text walked</em></p>');
+  });
 });
